var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AbstractTestSuiteExecutor, AbstractTestSuiteExecutorBuilder, TestSuiteBuilder, } from "@tmorin/ceb-inversion-testing-core";
/**
 * An implementation of {@link AbstractTestSuiteExecutor} dedicated for Jest.
 *
 * Instances should be created using the builder {@link JestTestSuiteExecutorBuilder}.
 */
export class JestTestSuiteExecutor extends AbstractTestSuiteExecutor {
    constructor(suite, before, provider, configurer, after) {
        super(suite, before, provider, configurer, after);
    }
    execute() {
        describe(this.suite.name, () => {
            for (const scenario of this.suite.scenarios) {
                describe(scenario.name, () => {
                    let containerBuilder;
                    let container;
                    beforeEach(() => __awaiter(this, void 0, void 0, function* () {
                        // before scenario
                        if (this.before) {
                            yield this.before();
                        }
                        // create the container builder
                        containerBuilder = this.provide();
                        // configure the builder with executor configuration
                        if (this.configure) {
                            yield Promise.resolve(this.configure(containerBuilder));
                        }
                        // configure the builder with scenario configuration
                        if (scenario.configure) {
                            yield Promise.resolve(scenario.configure(containerBuilder));
                        }
                        // initialize the container
                        container = yield containerBuilder.build().initialize();
                        // before execution
                        if (scenario.before) {
                            yield scenario.before(container);
                        }
                    }));
                    test("execution", () => __awaiter(this, void 0, void 0, function* () {
                        yield scenario.execute(container);
                    }));
                    afterEach(() => __awaiter(this, void 0, void 0, function* () {
                        // after execution
                        if (scenario.after) {
                            yield scenario.after(container);
                        }
                    }));
                    afterEach(() => __awaiter(this, void 0, void 0, function* () {
                        // dispose the container
                        if (container) {
                            yield container.dispose();
                        }
                    }));
                    afterEach(() => __awaiter(this, void 0, void 0, function* () {
                        // after scenario
                        if (this.after) {
                            yield this.after();
                        }
                    }));
                });
            }
        });
    }
}
/**
 * An extension of {@link AbstractTestSuiteExecutorBuilder} dedicated for Jest.
 *
 * @example run a test suite with an dummy scenario
 * ```typescript
 * import {TestScenarioBuilder, TestSuiteBuilder} from "@tmorin/ceb-inversion-testing-core";
 * import {JestTestSuiteExecutor} from "@tmorin/ceb-inversion-testing-jest"
 * JestTestSuiteExecutorBuilder.get(
 *  TestSuiteBuilder.get("test suite").scenario(
 *      TestScenarioBuilder.get("test scenario")
 *  )
 * ).test()
 * ```
 */
export class JestTestSuiteExecutorBuilder extends AbstractTestSuiteExecutorBuilder {
    constructor(suite) {
        super(suite);
    }
    /**
     * Create a builder.
     * @param suite the suite
     */
    static get(suite) {
        if (suite instanceof TestSuiteBuilder) {
            return new JestTestSuiteExecutorBuilder(suite.build());
        }
        return new JestTestSuiteExecutorBuilder(suite);
    }
    /**
     * Build the executor.
     */
    build() {
        return new JestTestSuiteExecutor(this._suite, this._before, this._provider, this._configurer, this._after);
    }
}
//# sourceMappingURL=index.js.map