import { AbstractTestSuiteExecutor, AbstractTestSuiteExecutorBuilder, Callback, CallbackWithContainerBuilder, ContainerBuilderProvider, TestSuite, TestSuiteBuilder, TestSuiteExecutor } from "@tmorin/ceb-inversion-testing-core";
/**
 * An implementation of {@link AbstractTestSuiteExecutor} dedicated for Jest.
 *
 * Instances should be created using the builder {@link JestTestSuiteExecutorBuilder}.
 */
export declare class JestTestSuiteExecutor extends AbstractTestSuiteExecutor<void> {
    constructor(suite: TestSuite, before?: Callback, provider?: ContainerBuilderProvider, configurer?: CallbackWithContainerBuilder, after?: Callback);
    execute(): void;
}
/**
 * An extension of {@link AbstractTestSuiteExecutorBuilder} dedicated for Jest.
 *
 * @example run a test suite with an dummy scenario
 * ```typescript
 * import {TestScenarioBuilder, TestSuiteBuilder} from "@tmorin/ceb-inversion-testing-core";
 * import {JestTestSuiteExecutor} from "@tmorin/ceb-inversion-testing-jest"
 * JestTestSuiteExecutorBuilder.get(
 *  TestSuiteBuilder.get("test suite").scenario(
 *      TestScenarioBuilder.get("test scenario")
 *  )
 * ).test()
 * ```
 */
export declare class JestTestSuiteExecutorBuilder extends AbstractTestSuiteExecutorBuilder<void> {
    protected constructor(suite: TestSuite);
    /**
     * Create a builder.
     * @param suite the suite
     */
    static get(suite: TestSuite | TestSuiteBuilder): JestTestSuiteExecutorBuilder;
    /**
     * Build the executor.
     */
    build(): TestSuiteExecutor<void>;
}
